import pickle
import settings
from pygame import Rect
import math


class Score(object):
    def __init__(self):
        self.score = 0
        try:
            self.highscores = pickle.load(open(settings.scorespth))
        except IOError:
            self.highscores = [(0, 'Jan Murre'), (0, 'Robrecht van Valkenburg'), (0, 'Jeroen Vloothuis')]

    def get_score_for(self, target):
        multiplier = 1.0
        x0, y0 = target.rect.center
        if self.point_in_triangle(x0, y0):
            multiplier = 1.5
        return int(multiplier * target.score)

    def capture(self, target):
        self.score += self.get_score_for(target)

    def _get_points(self):
        return self.score
    points = property(_get_points)

    def is_high_score(self):
        for score, person in self.highscores:
            if self.score>score:
                return True
        return False

    def save_highscore(self, person):
        for i, (score, old_person) in enumerate(self.highscores):
            if self.score>score:
                self.highscores.insert(i, (self.score, person))
                pickle.dump(self.highscores[:3], open(settings.scorespth, 'wb'))
                return
        raise ValueError("Score is not a highscore: %d"%self.score)

    def point_in_triangle(self, x0, y0):

        # x0,y0 = point to be tested
        #x1,y1 en x2,y2 en x3,y3 = points of triangle
        # if b0 = 0 then all points are on one line, call a quit
        
        x1, y1 = 112, 509
        x2, y2 = 669, 159
        x3, y3 = 706, 764

        b0 = ((x2 - x1) * (y3 - y1) - (x3 - x1) * (y2 - y1))
        b1 = (((x2 - x0) * (y3 - y0) - (x3 - x0) * (y2 - y0)) / (b0*1.0))
        b2 = (((x3 - x0) * (y1 - y0) - (x1 - x0) * (y3 - y0)) / (b0*1.0))
        b3 = 1 - b1 - b2

        if b1 > 0 and b2 > 0 and b3 > 0:
            return True
        else:
            return False
