from pygame.sprite import Sprite
from pygame.time import Clock

import sounds
import graphics

class UFO(Sprite):
    def __init__(self, x, y):
        super(UFO, self).__init__()
        self.current_image = 0
        self.images = [
            graphics.load_graphic('ufo-%d'%i) for i in range(3)]
        self.images_with_beam = [
            graphics.load_graphic('ufo-beam-%d'%i) for i in range(3)]

        self.image = self.images[0]
        self.rect = self.image.get_rect()
        
        self.move_to((x, y))
        self.is_beaming = False
        self.target = None

        self.beam_energy = 500
        self.clock = Clock()
        self.time_passed = 0 

    def move_to(self, position):
        self.rect.center = position

    def activateBeam(self):
        if self.beam_energy>20:
            self.is_beaming = True
            sounds.load_sound('beam').play()

    def deactivateBeam(self):
        self.is_beaming = False
        self.release_lock()
        sounds.load_sound('beam').stop()


    def ufo_image_index(self):
        self.current_image += 1
        
        if self.current_image/4>=len(self.images):
            self.current_image = 0
        return self.current_image/4

    def update(self):
        self.time_passed += self.clock.tick()
        if self.time_passed>100:
            if self.is_beaming:
                self.beam_energy -= 3
                if self.beam_energy<=0:
                    self.deactivateBeam()
                    self.beam_energy = 0
            else:
                self.beam_energy += 4
                if self.beam_energy>=500:
                    self.beam_energy = 500
            self.time_passed -= 100
        
        if self.is_beaming:
            self.image = self.images_with_beam[self.ufo_image_index()]
        else:
            self.image = self.images[self.ufo_image_index()]
        old_rect = self.rect
            
        self.rect = self.image.get_rect()
        self.rect.center = old_rect.center

    def release_lock(self):
        if self.target:
            self.target.release_beam_lock()
        self.target = None

    def acquire_target(self, target):
        """Acquire a transporter beam lock on a target"""
        if target is not self.target:
            target.lock_in_beam()
            self.release_lock()
            self.target = target
